@@ -7,35 +7,33 @@
 
 #include "thresholdoptions.h"
 
-
 #include <KEduVocDocument>
 #include <KEduVocWordtype>
 
-ThresholdOptions::ThresholdOptions(KEduVocDocument* doc, QWidget* parent) : QWidget(parent)
+ThresholdOptions::ThresholdOptions(KEduVocDocument *doc, QWidget *parent)
+    : QWidget(parent)
+    , m_doc{doc}
 {
     setupUi(this);
-    m_doc = doc;
 }
 
-
 void ThresholdOptions::updateWidgets()
 {
 }
 
-
 bool ThresholdOptions::isDefault()
 {
     return true;
     ///@todo
 }
 
-
 void ThresholdOptions::updateSettings()
 {
-
 }
 
 bool ThresholdOptions::hasChanged()
 {
     return false;
 }
+
+#include "moc_thresholdoptions.cpp"
