@@ -21,7 +21,7 @@ struct PersonConjugationSolutionWidgets {
     QLineEdit *input;
     QLabel *solution;
 
-    PersonConjugationSolutionWidgets(QGridLayout *layout, QWidget *parent = 0)
+    PersonConjugationSolutionWidgets(QGridLayout *layout, QWidget *parent = nullptr)
     {
         person = new QLabel(parent);
         person->setAlignment(Qt::AlignRight);
@@ -166,7 +166,7 @@ void ConjugationModeWidget::nextConjugationForm()
                 // move to the next input widget
                 m_personWidgets.at(i + 1)->input->setFocus();
             } else {
-                emit continueAction();
+                Q_EMIT continueAction();
             }
             return;
         }
@@ -187,3 +187,5 @@ void ConjugationModeWidget::setQuestionSound(const QUrl & /*soundUrl*/)
 void ConjugationModeWidget::setSolutionSound(const QUrl & /*soundUrl*/)
 {
 }
+
+#include "moc_conjugationmodewidget.cpp"
