@@ -14,7 +14,7 @@
 /// could move into KStringHandler eventually
 namespace ParleyStringHandlerOld
 {
-QString stripAccents(const QString& original)
+QString stripAccents(const QString &original)
 {
     QString noAccents;
     QString decomposed = original.normalized(QString::NormalizationForm_D);
@@ -30,12 +30,9 @@ QString stripAccents(const QString& original)
 
 using namespace Practice;
 
-WrittenPracticeValidator::WrittenPracticeValidator(int translation, KEduVocDocument* doc)
-    : m_entry(0),
-      m_doc(doc),
-      m_error(0),
-      m_speller(0),
-      m_spellerAvailable(false)
+WrittenPracticeValidator::WrittenPracticeValidator(int translation, KEduVocDocument *doc)
+    : m_doc(doc)
+    , m_error()
 {
     setLanguage(translation);
 }
@@ -45,7 +42,7 @@ WrittenPracticeValidator::~WrittenPracticeValidator()
     delete m_speller;
 }
 
-void WrittenPracticeValidator::setEntry(TestEntry* entry)
+void WrittenPracticeValidator::setEntry(TestEntry *entry)
 {
     m_entry = entry;
 }
@@ -68,14 +65,12 @@ void WrittenPracticeValidator::setLanguage(int translation)
 
     if (!m_speller->isValid()) {
         qDebug() << "No spellchecker for current language found: " << m_doc->identifier(m_translation).locale();
-        qDebug() << "Available dictionaries: " << m_speller->availableLanguages()
-                 << "\n names: " << m_speller->availableLanguageNames()
+        qDebug() << "Available dictionaries: " << m_speller->availableLanguages() << "\n names: " << m_speller->availableLanguageNames()
                  << "\n backends: " << m_speller->availableBackends();
         m_spellerAvailable = false;
     } else {
         m_spellerAvailable = true;
     }
-
 }
 
 bool WrittenPracticeValidator::spellcheckerAvailable()
@@ -83,9 +78,9 @@ bool WrittenPracticeValidator::spellcheckerAvailable()
     return m_spellerAvailable;
 }
 
-void WrittenPracticeValidator::validateAnswer(const QString& answer)
+void WrittenPracticeValidator::validateAnswer(const QString &answer)
 {
-    if (m_entry == 0) {
+    if (m_entry == nullptr) {
         qCritical() << "No entry set, cannot verify answer.";
         return;
     }
@@ -95,16 +90,16 @@ void WrittenPracticeValidator::validateAnswer(const QString& answer)
     qDebug() << "Correct answer should be: " << correct;
     m_error = {};
 
-    //Check for empty answers and valid answers first
+    // Check for empty answers and valid answers first
     if (answer.isEmpty()) {
         m_error |= TestEntry::Wrong;
         qDebug() << "Empty answer ";
     } else if (isCorrect(correct, answer)) {
         m_error |= TestEntry::Correct;
     } else {
-        //Check for all valid errors to build a list of
-        //possible mistakes. This provides us with useful information
-        //that we can use to give feedback to the user.
+        // Check for all valid errors to build a list of
+        // possible mistakes. This provides us with useful information
+        // that we can use to give feedback to the user.
         if (isPunctuationMistake(correct, answer)) {
             m_error |= TestEntry::Correct;
         } else if (isCapitalizationMistake(correct, answer)) {
@@ -128,27 +123,27 @@ QString WrittenPracticeValidator::getCorrectedAnswer()
     return m_correctedAnswer;
 }
 
-bool WrittenPracticeValidator::isCorrect(const QString& correct, const QString& answer)
+bool WrittenPracticeValidator::isCorrect(const QString &correct, const QString &answer)
 {
-    if (answer == correct ) {
+    if (answer == correct) {
         qDebug() << "Correct answer was given";
         return true;
     }
     return false;
 }
 
-bool WrittenPracticeValidator::isSynonymMistake(const QString& answer)
+bool WrittenPracticeValidator::isSynonymMistake(const QString &answer)
 {
-    foreach(KEduVocTranslation * synonym, m_entry->entry()->translation(m_entry->languageTo())->synonyms()) {
-        if (synonym->text() == answer ||
-                (Prefs::ignoreCapitalizationMistakes() && isCapitalizationMistake(synonym->text(), answer)) ||
-                (Prefs::ignoreAccentMistakes() && isAccentMistake(synonym->text(), answer)) ||
-                (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(synonym->text(), answer))) {
+    const QList<KEduVocTranslation *> synonyms = m_entry->entry()->translation(m_entry->languageTo())->synonyms();
+    for (KEduVocTranslation *synonym : synonyms) {
+        if (synonym->text() == answer || (Prefs::ignoreCapitalizationMistakes() && isCapitalizationMistake(synonym->text(), answer))
+            || (Prefs::ignoreAccentMistakes() && isAccentMistake(synonym->text(), answer))
+            || (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(synonym->text(), answer))) {
             qDebug() << "Synonym entered: " << synonym->text() << " answer: " << answer;
             m_correctedAnswer = synonym->text();
             m_error |= TestEntry::Synonym;
-            //only return true if accept these kinds of mistakes
-            //otherwise just set the error flag
+            // only return true if accept these kinds of mistakes
+            // otherwise just set the error flag
             if (Prefs::countSynonymsAsCorrect()) {
                 return true;
             }
@@ -157,22 +152,21 @@ bool WrittenPracticeValidator::isSynonymMistake(const QString& answer)
     return false;
 }
 
-bool WrittenPracticeValidator::isCapitalizationMistake(const QString& original, const QString& answer)
+bool WrittenPracticeValidator::isCapitalizationMistake(const QString &original, const QString &answer)
 {
-    if (answer.toLower() == original.toLower() ||
-            (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(original.toLower(),answer.toLower()))) {
+    if (answer.toLower() == original.toLower() || (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(original.toLower(), answer.toLower()))) {
         qDebug() << "CapitalizationMistake: " << original << " answer: " << answer;
         m_error |= TestEntry::CapitalizationMistake;
         m_correctedAnswer = answer;
-        //only return true if accept these kinds of mistakes
-        //otherwise just set the error flag
+        // only return true if accept these kinds of mistakes
+        // otherwise just set the error flag
         if (Prefs::ignoreCapitalizationMistakes())
             return true;
     }
     return false;
 }
 
-bool WrittenPracticeValidator::isPunctuationMistake(const QString& original, const QString& answer)
+bool WrittenPracticeValidator::isPunctuationMistake(const QString &original, const QString &answer)
 {
     QString ans = answer;
     QString orig = original;
@@ -180,26 +174,25 @@ bool WrittenPracticeValidator::isPunctuationMistake(const QString& original, con
         qDebug() << "PunctuationMistake: " << original << " answer: " << answer;
         m_error |= TestEntry::PunctuationMistake;
         m_correctedAnswer = answer;
-        //only return true if accept these kinds of mistakes
-        //otherwise just set the error flag
+        // only return true if accept these kinds of mistakes
+        // otherwise just set the error flag
         if (Prefs::ignorePunctuationMistakes())
             return true;
     }
     return false;
 }
 
-bool WrittenPracticeValidator::isAccentMistake(const QString& original, const QString& answer)
+bool WrittenPracticeValidator::isAccentMistake(const QString &original, const QString &answer)
 {
     QString stripedOriginal = ParleyStringHandlerOld::stripAccents(original);
     QString stripedAnswer = ParleyStringHandlerOld::stripAccents(answer);
-    if (stripedOriginal == stripedAnswer ||
-            (Prefs::ignoreCapitalizationMistakes() && isCapitalizationMistake(stripedOriginal, stripedAnswer)) ||
-            (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(stripedOriginal, stripedAnswer))) {
+    if (stripedOriginal == stripedAnswer || (Prefs::ignoreCapitalizationMistakes() && isCapitalizationMistake(stripedOriginal, stripedAnswer))
+        || (Prefs::ignorePunctuationMistakes() && isPunctuationMistake(stripedOriginal, stripedAnswer))) {
         qDebug() << "AccentMistake: " << original << " answer: " << answer;
         m_error |= TestEntry::AccentMistake;
         m_correctedAnswer = answer;
-        //only return true if accept these kinds of mistakes
-        //otherwise just set the error flag
+        // only return true if accept these kinds of mistakes
+        // otherwise just set the error flag
         if (Prefs::ignoreAccentMistakes()) {
             return true;
         }
